@@ -1,8 +1,8 @@
 #include <glib.h>
 #include <gtk/gtk.h>
-#include "Widgets/pixbuf-cache.h"
+#include "pixbuf-cache.h"
 
-#define CYCLES 128
+#define CYCLES 100
 
 int main (int argc, char **argv)
 {
@@ -13,7 +13,7 @@ int main (int argc, char **argv)
 
     l = g_main_loop_new(NULL, TRUE); 
     pixbuf_cache_create();
-    for(;i>0;i--){
+    for(i=CYCLES;i>0;i--){
         GdkPixbuf *pb = gdk_pixbuf_new_from_file("test.png", NULL);
         if(pb) {
             pixbuf_cache_add_icon(i, "test.png", pb);
@@ -26,8 +26,8 @@ int main (int argc, char **argv)
         g_object_unref(node->data);
     }
     g_list_free(list);
-    g_timeout_add_seconds(30, g_main_loop_quit,l);
-    printf("quitting in 30 seconds\n");
+    g_timeout_add_seconds(40, g_main_loop_quit,l);
+    printf("quitting in 40 seconds\n");
     g_main_loop_run(l);
 
     pixbuf_cache_destroy();
